# Daskpeeker

[![Documentation Status](https://readthedocs.org/projects/daskpeeker/badge/?version=latest)](https://jelm.readthedocs.io/en/daskpeeker/?badge=latest)
[![codeclimate](https://img.shields.io/codeclimate/maintainability/endremborza/daskpeeker.svg)](https://codeclimate.com/github/endremborza/daskpeeker)
[![codecov](https://img.shields.io/codecov/c/github/endremborza/daskpeeker)](https://codecov.io/gh/endremborza/daskpeeker)
[![pypi](https://img.shields.io/pypi/v/daskpeeker.svg)](https://pypi.org/project/daskpeeker/)

A dashboard to peek at different slices of dask dataframes
